@@ -34,7 +34,7 @@ class JSONField(models.TextField):
             value = json.loads(value)
         return value
 
-    def from_db_value(self, value, expression, connection, context):
+    def from_db_value(self, value, expression, connection):
         if isinstance(value, str):
             value = json.loads(value)
         return value
